@@ -22,16 +22,18 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+import base64
+import hashlib
+import hmac
+import json
+import logging
 import os
 import time
-import logging
-from json import JSONDecodeError
-
+import uuid
 import httpx
 
 from .login import get_token
-
-from ..config import ErrorType, ErrorMessage
+from ..config import Configs, ErrorType, ErrorMessage
 from ..errors import (
     HTTPError,
     BadRequestError,
@@ -41,7 +43,11 @@ from ..errors import (
     RateLimitError,
     YayServerError,
 )
-from ..utils import Configs, generate_uuid, load_session, save_session, decrypt
+
+try:
+    from json.decoder import JSONDecodeError
+except ImportError:
+    JSONDecodeError = ValueError
 
 
 current_path = os.path.abspath(os.getcwd())
@@ -57,19 +63,20 @@ class API:
         timeout=30,
         err_lang="ja",
         base_path=current_path + "/config/",
-        save_session=True,
-        session_filename="session",
+        save_cookie_file=True,
+        cookie_filename="cookies",
         loglevel=logging.INFO,
     ):
         self.yaylib_version = Configs.YAYLIB_VERSION
         self.api_version = Configs.YAY_API_VERSION
         self.api_key = Configs.YAY_API_KEY
         self.fernet = None
-        self.secret_key = None
+        self._secret_key = None
 
         self.proxy = {}
         if proxy is not None:
-            self.proxy["https"] = proxy
+            self.proxy["http://"] = proxy
+            self.proxy["https://"] = proxy
 
         self.max_retries = max_retries
         self.retry_statuses = [500, 502, 503, 504]
@@ -77,14 +84,15 @@ class API:
         self.timeout = timeout
         self.err_lang = err_lang
         self.base_path = base_path
-        self.save_session = save_session
-        self.session_filename = session_filename
+        self.save_cookie_file = save_cookie_file
+        self.cookie_filename = cookie_filename
+        self._cookies = {}
 
         self._generate_all_uuids()
         self.session = httpx.Client(proxies=self.proxy, timeout=self.timeout)
         self.session.headers.update(Configs.REQUEST_HEADERS)
         self.session.headers.update({"X-Device-Uuid": self.device_uuid})
-        if access_token:
+        if access_token is not None:
             self.session.headers.setdefault("Authorization", f"Bearer {access_token}")
 
         self.logger = logging.getLogger("yaylib version: " + self.yaylib_version)
@@ -96,6 +104,8 @@ class API:
         ch.setLevel(loglevel)
         ch.setFormatter(logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 
+        # check if a stream handler is already present in the logger
+        # to avoid adding duplicate handlers
         handler_existed = False
         for handler in self.logger.handlers:
             if isinstance(handler, logging.StreamHandler):
@@ -130,6 +140,7 @@ class API:
         auth_retry_count = 0
         max_auth_retries = 2
 
+        # retry the request based on max_retries
         for i in range(self.max_retries):
             time.sleep(backoff_duration)
 
@@ -145,47 +156,51 @@ class API:
                 method, endpoint, params=params, json=payload, headers=headers
             )
 
-            if self.save_session is True and response.status_code == 401:
+            if self.save_cookie_file is True and response.status_code == 401:
+                # remove the cookie file and stop the proccessing if refresh token has expired
+                # (/api/v1/oauth/token in the endpoint which means already retried but failed)
                 if "/api/v1/oauth/token" in endpoint:
-                    os.remove(self.base_path + self.session_filename + ".json")
-                    message = "Refresh token expired. Try logging in again."
-                    raise AuthenticationError(message)
-
-                auth_retry_count += 1
-                self.logger.debug("Access token expired. Refreshing tokens...")
-
-                if auth_retry_count < max_auth_retries:
-                    session = load_session(
-                        base_path=self.base_path, session_filename=self.session_filename
+                    os.remove(self.base_path + self.cookie_filename + ".json")
+                    raise AuthenticationError(
+                        "Refresh token expired. Try logging in again."
                     )
 
-                    if session is not None and self.fernet is not None:
-                        session = decrypt(fernet=self.fernet, session=session)
-                        refresh_token = session["refresh_token"]
+                auth_retry_count += 1
+
+                if auth_retry_count < max_auth_retries:
+                    # refresh access token using the stored refresh token
+                    self.logger.debug("Access token expired. Refreshing tokens...")
+
+                    cookies = self.load_cookies()
+
+                    if cookies is not None and self.fernet is not None:
+                        cookies = self.decrypt_cookies(self.fernet, cookies)
                         response = get_token(
                             self,
                             grant_type="refresh_token",
-                            refresh_token=refresh_token,
+                            refresh_token=cookies.get("refresh_token"),
                         )
-                        save_session(
-                            base_path=self.base_path,
-                            session_filename=self.session_filename,
-                            fernet=self.fernet,
-                            access_token=response.access_token,
-                            refresh_token=response.refresh_token,
-                            user_id=response.user_id,
+                        self._cookies.update(
+                            {
+                                "access_token": response.access_token,
+                                "refresh_token": response.refresh_token,
+                                "user_id": response.user_id,
+                            }
                         )
+                        self.save_cookies(self.cookies)
+
                         self.session.headers[
                             "Authorization"
                         ] = f"Bearer {response.access_token}"
+
+                        # continue to the next retry iteration
                         continue
 
                 else:
-                    os.remove(self.base_path + self.session_filename + ".json")
-                    message = (
+                    os.remove(self.base_path + self.cookie_filename + ".json")
+                    raise AuthenticationError(
                         "Maximum authentication retries exceeded. Try logging in again."
                     )
-                    raise AuthenticationError(message)
 
             if response.status_code not in self.retry_statuses:
                 break
@@ -235,6 +250,129 @@ class API:
             return self._construct_response(response, data_type)
         return response
 
+    @property
+    def cookies(self):
+        return self._cookies
+
+    @cookies.setter
+    def cookies(self, cookies):
+        result = all(key in cookies for key in Configs.COOKIE_PROPERTIES)
+        if result is False:
+            raise ValueError("Invalid cookie properties.")
+        self._cookies = cookies
+
+    @property
+    def access_token(self):
+        auth_header = self.session.headers.get("Authorization")
+        if auth_header is not None:
+            return self.cookies.get("access_token") or auth_header.replace(
+                "Bearer ", ""
+            )
+        return self.cookies.get("access_token")
+
+    @property
+    def refresh_token(self):
+        return self.cookies.get("refresh_token")
+
+    @property
+    def user_id(self):
+        return self.cookies.get("user_id")
+
+    @property
+    def secret_key(self):
+        return self._secret_key
+
+    @secret_key.setter
+    def secret_key(self, value):
+        self._secret_key = value
+
+    @property
+    def client_version(self):
+        return Configs.YAY_VERSION_NAME
+
+    @staticmethod
+    def encrypt_cookies(fernet, cookies):
+        access_token = cookies.get("access_token")
+        refresh_token = cookies.get("refresh_token")
+        cookies.update(
+            {
+                "access_token": fernet.encrypt(access_token.encode()).decode(),
+                "refresh_token": fernet.encrypt(refresh_token.encode()).decode(),
+            }
+        )
+        return cookies
+
+    @staticmethod
+    def decrypt_cookies(fernet, cookies):
+        access_token = cookies.get("access_token")
+        refresh_token = cookies.get("refresh_token")
+        cookies.update(
+            {
+                "access_token": fernet.decrypt(access_token).decode(),
+                "refresh_token": fernet.decrypt(refresh_token).decode(),
+            }
+        )
+        return cookies
+
+    @staticmethod
+    def generate_uuid(uuid_type=True):
+        generated_uuid = str(uuid.uuid4())
+        if uuid_type:
+            return generated_uuid
+        else:
+            return generated_uuid.replace("-", "")
+
+    @staticmethod
+    def generate_signed_info(uuid, timestamp, shared_key=False):
+        shared_key = Configs.YAY_SHARED_KEY if shared_key is True else ""
+        return hashlib.md5(
+            (Configs.YAY_API_KEY + uuid + str(timestamp) + shared_key).encode()
+        ).hexdigest()
+
+    @staticmethod
+    def generate_signed_version():
+        return base64.b64encode(
+            hmac.new(
+                Configs.YAY_API_VERSION_KEY.encode(),
+                "yay_android/{}".format(Configs.YAY_API_VERSION).encode(),
+                hashlib.sha256,
+            ).digest()
+        ).decode("utf-8")
+
+    def load_cookies(self, email=None):
+        if not os.path.exists(self.base_path + self.cookie_filename + ".json"):
+            return None
+
+        with open(self.base_path + self.cookie_filename + ".json", "r") as f:
+            cookies = json.load(f)
+
+        result = all(key in cookies for key in Configs.COOKIE_PROPERTIES)
+        if result is False:
+            os.remove(self.base_path + self.cookie_filename + ".json")
+            raise ValueError("Invalid cookie properties.")
+
+        # check if the provided email matches the stored email in cookies
+        # if not, set cookies to none
+        if email is not None and email != cookies.get("email"):
+            cookies = None if email != cookies.get("email") else cookies
+        if self.fernet is not None and cookies is not None:
+            cookies = self.decrypt_cookies(self.fernet, cookies)
+
+        return cookies
+
+    def save_cookies(self, cookies):
+        if cookies.get("email") is None:
+            cookies["email"] = self.load_cookies().get("email")
+
+        result = all(key in cookies for key in Configs.COOKIE_PROPERTIES)
+        if result is False:
+            raise ValueError("Invalid cookie properties.")
+
+        cookies = self.encrypt_cookies(self.fernet, cookies)
+
+        with open(self.base_path + self.cookie_filename + ".json", "w") as f:
+            json.dump(cookies, f, indent=4)
+
     @staticmethod
     def _construct_response(data, data_type):
         if data_type is not None:
@@ -267,6 +405,7 @@ class API:
             raise YayServerError(formatted_response)
         if response.status_code and not 200 <= response.status_code < 300:
             raise HTTPError(formatted_response)
+
         return formatted_response
 
     def _translate_error_message(self, response):
@@ -285,5 +424,5 @@ class API:
             return response
 
     def _generate_all_uuids(self):
-        self.device_uuid = generate_uuid(True)
-        self.uuid = generate_uuid(True)
+        self.device_uuid = self.generate_uuid(True)
+        self.uuid = self.generate_uuid(True)
