@@ -25,17 +25,10 @@ SOFTWARE.
 from datetime import datetime
 from cryptography.fernet import Fernet
 
-from ..config import Configs, Endpoints
+from ..config import Endpoints
 from ..errors import AuthenticationError, ForbiddenError
 from ..responses import LoginUserResponse, LoginUpdateResponse, TokenResponse
-from ..utils import (
-    Colors,
-    console_print,
-    load_session,
-    save_session,
-    decrypt,
-    signed_info_calculating,
-)
+from ..utils import Colors, console_print
 
 
 def change_email(
@@ -114,23 +107,21 @@ def is_valid_token(self, access_token: str):
 def login_with_email(
     self, email: str, password: str, secret_key: str = None
 ) -> LoginUserResponse:
-    if self.save_session:
-        session = load_session(
-            base_path=self.base_path,
-            session_filename=self.session_filename,
-            check_email=email,
-        )
-        if session is not None and secret_key is not None:
+    if self.save_cookie_file:
+        cookies = self.load_cookies(email)
+
+        if cookies is not None and secret_key is not None:
             self.secret_key = secret_key
             self.fernet = Fernet(secret_key)
-            session = decrypt(fernet=self.fernet, session=session)
+            self.cookies = self.decrypt_cookies(self.fernet, cookies)
             self.session.headers.setdefault(
-                "Authorization", f"Bearer {session['access_token']}"
+                "Authorization", f"Bearer {self.access_token}"
             )
-            self.logger.info(f"Successfully logged in as '{session['user_id']}'")
-            return LoginUserResponse(session)
-        elif session is not None:
-            message = f"{Colors.WARNING}Session file found. The 'secret_key' must be provided to decrypt the credentials.{Colors.RESET}"
+            self.logger.info(f"Successfully logged in as '{self.user_id}'")
+            return LoginUserResponse(cookies)
+
+        elif cookies is not None:
+            message = f"{Colors.WARNING}Cookie file found. The 'secret_key' must be provided to decrypt the credentials.{Colors.RESET}"
             console_print(message)
 
     response = self._make_request(
@@ -151,9 +142,9 @@ def login_with_email(
     self.session.headers.setdefault("Authorization", f"Bearer {response.access_token}")
     self.logger.info(f"Successfully logged in as '{response.user_id}'")
 
-    if self.save_session:
+    if self.save_cookie_file:
         secret_key = Fernet.generate_key()
-        self.secret_key = secret_key
+        self.secret_key = secret_key.decode()
         self.fernet = Fernet(secret_key)
 
         console_print(
@@ -162,15 +153,14 @@ def login_with_email(
             "For more information, visit: https://github.com/qvco/yaylib/blob/master/docs/API-Reference/login/login.md",
         )
 
-        save_session(
-            base_path=self.base_path,
-            session_filename=self.session_filename,
-            fernet=self.fernet,
-            access_token=response.access_token,
-            refresh_token=response.refresh_token,
-            user_id=response.user_id,
-            email=email,
-        )
+        self.cookies = {
+            "access_token": response.access_token,
+            "refresh_token": response.refresh_token,
+            "user_id": response.user_id,
+            "email": email,
+        }
+
+        self.save_cookies(self.cookies)
 
     return response
 
@@ -184,6 +174,7 @@ def logout(self, access_token: str = None):
             payload={"uuid": self.uuid},
             access_token=access_token,
         )
+        self._cookies = {}
         self.session.headers.pop("Authorization", None)
         self.logger.info("User has logged out.")
         return response
@@ -211,7 +202,7 @@ def restore_user(self, user_id: int, access_token: str = None) -> LoginUserRespo
             "api_key": self.api_key,
             "uuid": self.uuid,
             "timestamp": timestamp,
-            "signed_info": signed_info_calculating(self.device_uuid, timestamp),
+            "signed_info": self.generate_signed_info(self.device_uuid, timestamp),
         },
         access_token=access_token,
     )
