@@ -240,7 +240,7 @@ from .api.user import (
     get_user_without_leaving_footprint,
     get_users,
     refresh_counter,
-    register_user,
+    register,
     remove_user_avatar,
     remove_user_cover,
     report_user,
@@ -269,6 +269,7 @@ from .models import (
     CreateGroupQuota,
     Footprint,
     GifImageCategory,
+    Group,
     Message,
     Post,
     PresignedUrl,
@@ -294,7 +295,6 @@ from .responses import (
     GamesResponse,
     GenresResponse,
     GroupCategoriesResponse,
-    GroupResponse,
     GroupsRelatedResponse,
     GroupsResponse,
     GroupThreadListResponse,
@@ -340,8 +340,8 @@ class Client(API):
         - timeout: int - (optional)
         - err_lang: str - (optional)
         - base_path: str - (optional)
-        - save_session: bool - (optional)
-        - session_filename: str - (optional)
+        - save_cookie_file: bool - (optional)
+        - cookie_filename: str - (optional)
         - loglevel: int - (optional)
 
     <https://github.com/qvco/yaylib>
@@ -1171,7 +1171,7 @@ class Client(API):
         """
         return get_create_group_quota(self, access_token)
 
-    def get_group(self, group_id: int, access_token: str = None) -> GroupResponse:
+    def get_group(self, group_id: int, access_token: str = None) -> Group:
         """
 
         サークルの詳細を取得します
@@ -1476,7 +1476,7 @@ class Client(API):
         allow_members_to_post_url: bool = None,
         guidelines: str = None,
         access_token: str = None,
-    ) -> GroupResponse:
+    ) -> Group:
         """
 
         サークルを編集します
@@ -1703,7 +1703,7 @@ class Client(API):
 
         Parameteres
         -----------
-            - image_type: str - (required): "post", "user_avatar" のどちらか
+            - image_type: str - (required): 画像の種類
             - image_path: str - (required): "画像のパス
 
         """
@@ -2952,7 +2952,7 @@ class Client(API):
         """
         return refresh_counter(self, counter, access_token)
 
-    def register_user(
+    def register(
         self,
         email: str,
         email_grant_token: str,
@@ -2974,7 +2974,7 @@ class Client(API):
         Register user
 
         """
-        return register_user(
+        return register(
             self,
             email,
             email_grant_token,
