@@ -26,10 +26,10 @@ from enum import Enum
 
 
 class Configs:
-    YAYLIB_VERSION = "1.0.6"
-    YAY_API_VERSION = "3.20"
-    YAY_VERSION_NAME = "3.20.1"
-    YAY_API_VERSION_KEY = "d4420f4943bebe2831c20b2b4cb4a8c1"
+    YAYLIB_VERSION = "1.0.9"
+    YAY_API_VERSION = "3.21"
+    YAY_VERSION_NAME = "3.21.0"
+    YAY_API_VERSION_KEY = "c687e24f6a454896891acd68868c7979"
     YAY_API_KEY = "ccd59ee269c01511ba763467045c115779fcae3050238a252f1bd1a4b65cfec6"
     YAY_SHARED_KEY = "yayZ1"
     YAY_STORE_KEY = "yayZ1payment"
@@ -43,6 +43,7 @@ class Configs:
     YAY_PRODUCTION_HOST = "api.yay.space"
     ID_CARD_CHECK_HOST_PRODUCTION = "idcardcheck.com"
     ID_CARD_CHECK_HOST_STAGING = "stg.idcardcheck.com"
+    COOKIE_PROPERTIES = ["access_token", "refresh_token", "user_id", "email"]
     USER_AGENT = "android 11 (3.5x 1440x2960 Galaxy S9)"
     REQUEST_HEADERS = {
         "Host": YAY_PRODUCTION_HOST,
@@ -245,6 +246,7 @@ class ErrorType(Enum):
     PasswordTooLong = -408
     PasswordNotAllowed = -409
     CommonPassword = -410
+    EmailNotAuthorized = -411
     UnableToMovePostToThread = -412
     UnableToPostUrl = -413
     UnableToSetCall = -977
@@ -348,6 +350,7 @@ class ErrorMessage(Enum):
     PasswordTooLong = "パスワードが長すぎます"
     PasswordNotAllowed = "他のパスワードを使用してください。無効な文字列が含まれています"
     CommonPassword = "他のパスワードを使用してください。文字列や数字、または記号などの組み合わせをお試しください"
+    EmailNotAuthorized = "このメールアドレスを使用するには承認される必要があります"
     UnableToMovePostToThread = "投稿をスレッドに移動できません"
     UnableToPostUrl = "URLを投稿できません"
     UnableToSetCall = "通話を開始できませんでした"
