@@ -30,23 +30,28 @@ class Activity:
         "data",
         "id",
         "created_at",
-        "created_at_parsed",
         "type",
         "user",
         "from_post",
         "to_post",
         "group",
         "followers",
+        "followers_count",
         "from_post_ids",
         "vip_reward",
         "is_bulk_invitation",
+        "content_preview",
+        "title",
+        "body",
+        "url",
+        "birthday_users",
+        "birthday_users_count",
     )
 
     def __init__(self, data):
         self.data = data
         self.id = data.get("id")
         self.created_at = data.get("created_at")
-        self.created_at_parsed = parse_datetime(data.get("created_at"))
         self.type = data.get("type")
 
         self.user = data.get("user")
@@ -69,9 +74,22 @@ class Activity:
         if self.followers is not None:
             self.followers = [User(follower) for follower in self.followers]
 
+        self.followers_count = data.get("followers_count")
         self.from_post_ids = data.get("from_post_ids")
         self.vip_reward = data.get("vip_reward")
         self.is_bulk_invitation = data.get("is_bulk_invitation")
+        self.content_preview = data.get("content_preview")
+        self.title = data.get("title")
+        self.body = data.get("body")
+        self.url = data.get("url")
+
+        self.birthday_users = data.get("birthday_users")
+        if self.birthday_users is not None:
+            self.birthday_users = [
+                User(birthday_user) for birthday_user in self.birthday_users
+            ]
+
+        self.birthday_users_count = data.get("birthday_users_count")
 
     def __repr__(self):
         return f"Activity(data={self.data})"
@@ -105,7 +123,7 @@ class Bgm:
 
 
 class CallGiftHistory:
-    __slots__ = ("data", "gifts_count", "sent_at", "sent_at_parsed", "sender")
+    __slots__ = ("data", "gifts_count", "sent_at", "sender")
 
     def __init__(self, data):
         self.data = data
@@ -117,7 +135,6 @@ class CallGiftHistory:
             ]
 
         self.sent_at = data.get("sent_at")
-        self.sent_at_parsed = parse_datetime(data.get("sent_at"))
 
         self.sender = data.get("sender")
         if self.sender is not None:
@@ -133,7 +150,6 @@ class ChatRoom:
         "id",
         "unread_count",
         "updated_at",
-        "updated_at_parsed",
         "members",
         "background",
         "last_message",
@@ -149,7 +165,6 @@ class ChatRoom:
         self.id = data.get("id")
         self.unread_count = data.get("unread_count")
         self.updated_at = data.get("updated_at")
-        self.updated_at_parsed = parse_datetime(data.get("updated_at"))
 
         self.members = data.get("members")
         if self.members is not None:
@@ -451,7 +466,7 @@ class Error:
 
 
 class Footprint:
-    __slots__ = ("data", "user", "visited_at", "visited_at_parsed", "id")
+    __slots__ = ("data", "user", "visited_at", "id")
 
     def __init__(self, data):
         self.data = data
@@ -461,7 +476,6 @@ class Footprint:
             self.user = User(self.user)
 
         self.visited_at = data.get("visited_at")
-        self.visited_at_parsed = parse_datetime(data.get("visited_at"))
         self.id = data.get("id")
 
     def __repr__(self):
@@ -597,15 +611,16 @@ class Group:
         "id",
         "topic",
         "description",
-        "user_id",
         "groups_users_count",
         "posts_count",
+        "user_id",
         "threads_count",
         "highlighted_count",
         "views_count",
         "related_count",
         "secret",
         "gender",
+        "place",
         "hide_reported_posts",
         "hide_conference_call",
         "is_private",
@@ -613,7 +628,8 @@ class Group:
         "only_mobile_verified",
         "call_timeline_display",
         "updated_at",
-        "updated_at_parsed",
+        "group_icon",
+        "group_icon_thumbnail",
         "cover_image",
         "cover_image_thumbnail",
         "generation_groups_limit",
@@ -621,6 +637,7 @@ class Group:
         "is_joined",
         "is_pending",
         "group_category_id",
+        "homepage",
         "unread_counts",
         "moderator_ids",
         "seizable",
@@ -657,6 +674,7 @@ class Group:
         self.related_count = data.get("related_count")
         self.secret = data.get("secret")
         self.gender = data.get("gender")
+        self.place = data.get("place")
         self.hide_reported_posts = data.get("hide_reported_posts")
         self.hide_conference_call = data.get("hide_conference_call")
         self.is_private = data.get("is_private")
@@ -664,7 +682,8 @@ class Group:
         self.only_mobile_verified = data.get("only_mobile_verified")
         self.call_timeline_display = data.get("call_timeline_display")
         self.updated_at = data.get("updated_at")
-        self.updated_at_parsed = parse_datetime(data.get("updated_at"))
+        self.group_icon = data.get("group_icon")
+        self.group_icon_thumbnail = data.get("group_icon_thumbnail")
         self.cover_image = data.get("cover_image")
         self.cover_image_thumbnail = data.get("cover_image_thumbnail")
         self.generation_groups_limit = data.get("generation_groups_limit")
@@ -676,6 +695,7 @@ class Group:
         self.is_joined = data.get("is_joined")
         self.is_pending = data.get("is_pending")
         self.group_category_id = data.get("group_category_id")
+        self.homepage = data.get("homepage")
         self.unread_counts = data.get("unread_counts")
         self.moderator_ids = data.get("moderator_ids")
         self.seizable = data.get("seizable")
@@ -918,9 +938,7 @@ class Post:
         "likes_count",
         "created_at",
         "updated_at",
-        "updated_at_parsed",
         "edited_at",
-        "edited_at_parsed",
         "liked",
         "tag",
         "reposts_count",
@@ -977,9 +995,7 @@ class Post:
         self.likes_count = data.get("likes_count")
         self.created_at = data.get("created_at")
         self.updated_at = data.get("updated_at")
-        self.updated_at_parsed = parse_datetime(data.get("updated_at"))
         self.edited_at = data.get("edited_at")
-        self.edited_at_parsed = parse_datetime(data.get("edited_at"))
         self.liked = data.get("liked")
         self.tag = data.get("tag")
         self.reposts_count = data.get("reposts_count")
@@ -1192,7 +1208,6 @@ class Review:
         "user",
         "reviewer",
         "created_at",
-        "created_at_parsed",
         "mutual_review",
     )
 
@@ -1208,7 +1223,6 @@ class Review:
 
         self.reviewer = data.get("reviewer")
         self.created_at = data.get("created_at")
-        self.created_at_parsed = parse_datetime(data.get("created_at"))
         self.mutual_review = data.get("mutual_review")
 
     def __repr__(self):
@@ -1518,9 +1532,7 @@ class ThreadInfo:
         "unread_count",
         "posts_count",
         "created_at",
-        "created_at_parsed",
         "updated_at",
-        "updated_at_parsed",
         "thread_icon",
         "is_joined",
         "new_updates",
@@ -1542,9 +1554,7 @@ class ThreadInfo:
         self.unread_count = data.get("unread_count")
         self.posts_count = data.get("posts_count")
         self.created_at = data.get("created_at")
-        self.created_at_parsed = parse_datetime(data.get("created_at"))
         self.updated_at = data.get("updated_at")
-        self.updated_at_parsed = parse_datetime(data.get("updated_at"))
         self.thread_icon = data.get("thread_icon")
         self.is_joined = data.get("is_joined")
         self.new_updates = data.get("new_updates")
@@ -1565,9 +1575,7 @@ class User:
         "gender",
         "generation",
         "last_logged_in_at",
-        "last_logged_in_at_parsed",
         "created_at",
-        "created_at_parsed",
         "badge",
         "followers_count",
         "followings_count",
@@ -1601,7 +1609,6 @@ class User:
         "connected_by",
         "contact_phones",
         "updated_time_millis",
-        "updated_time_millis_parsed",
     )
 
     def __init__(self, data):
@@ -1613,9 +1620,7 @@ class User:
         self.gender = data.get("gender")
         self.generation = data.get("generation")
         self.last_logged_in_at = data.get("last_logged_in_at")
-        self.last_logged_in_at_parsed = parse_datetime(data.get("last_logged_in_at"))
         self.created_at = data.get("created_at")
-        self.created_at_parsed = parse_datetime(data.get("created_at"))
         self.badge = data.get("title")
         self.followers_count = data.get("followers_count")
         self.followings_count = data.get("followings_count")
@@ -1655,9 +1660,6 @@ class User:
         self.connected_by = data.get("connected_by")
         self.contact_phones = data.get("contact_phones")
         self.updated_time_millis = data.get("updated_time_millis")
-        self.updated_time_millis_parsed = parse_datetime(
-            data.get("updated_time_millis")
-        )
 
     def __repr__(self):
         return f"User(data={self.data})"
@@ -1745,7 +1747,6 @@ class WalletTransaction:
         self.data = data
         self.id = data.get("id")
         self.created_at = data.get("created_at")
-        self.created_at_parsed = parse_datetime(data.get("created_at"))
         self.description = data.get("description")
         self.amount = data.get("amount")
 
